@@ -10,9 +10,14 @@ from deposit.utils.fnc_files import (as_url, get_updated_local_url)
 from deposit.utils.fnc_geometry import (add_srid_to_wkt)
 from deposit.query.parse import (remove_quoted, remove_bracketed_all)
 
+from cryptography.fernet import Fernet, InvalidToken
 from collections import defaultdict
 import datetime
+import hashlib
+import base64
+import uuid
 import json
+import html
 import re
 import os
 
@@ -124,9 +129,9 @@ def legacy_data_to_store(data, store, path, progress = None):
 		)
 		
 		for obj_id in data["classes"][name]["objects"]:
-			if obj_id not in data["objects"]:
+			if str(obj_id) not in data["objects"]:
 				continue
-			store.G.add_class_child(name, int(obj_id) + 1)
+			store.G.add_class_child(name, obj_id + 1)
 			class_lookup[obj_id].add(name)
 		
 		for name_subclass in data["classes"][name]["subclasses"]:
@@ -153,7 +158,7 @@ def legacy_data_to_store(data, store, path, progress = None):
 			cnt += 1
 		
 		obj_data = dict(
-			id = obj_id,
+			id = int(obj_id),
 			descriptors = {},
 			locations = {},
 		)
@@ -208,16 +213,17 @@ def legacy_data_to_store(data, store, path, progress = None):
 		
 		for label in data["objects"][obj_id]["relations"]:
 			for obj_id_tgt in data["objects"][obj_id]["relations"][label]["objects"]:
-				if obj_id_tgt not in data["objects"]:
+				if str(obj_id_tgt) not in data["objects"]:
 					continue
 				weight = None
 				if ("weights" in data["objects"][obj_id]["relations"][label]) and \
-					(obj_id_tgt in data["objects"][obj_id]["relations"][label]["weights"]):
-					weight = data["objects"][obj_id]["relations"][label]["weights"][obj_id_tgt]
+					(str(obj_id_tgt) in data["objects"][obj_id]["relations"][label]["weights"]):
+					weight = data["objects"][obj_id]["relations"][label]["weights"][str(obj_id_tgt)]
 				store.G.add_object_relation(int(obj_id) + 1, int(obj_id_tgt) + 1, label, weight)
-				for src_class in class_lookup[obj_id]:
+				for src_class in class_lookup[int(obj_id)]:
 					for tgt_class in class_lookup[obj_id_tgt]:
 						collect_rels.add((src_class, tgt_class, label))
+	
 	collect_rels = cls_rels_done.difference(cls_rels_done)
 	for src_class, tgt_class, label in collect_rels:
 		store.G.add_class_relation(src_class, tgt_class, label)
@@ -481,3 +487,74 @@ def load_user_tool(path):
 				))
 	
 	return data
+
+def get_machine_key():
+	
+	uid = uuid.getnode()
+	uid_ = uuid.getnode()
+	if uid != uid_:
+		key = "rO7%83CsJxD#"
+	else:
+		key = str(uid)
+	key = base64.urlsafe_b64encode(hashlib.sha256(key.encode()).digest())
+	
+	return key
+
+def encrypt_password(password):
+	
+	token = Fernet(get_machine_key()).encrypt(password.encode())
+	
+	return token.decode()
+
+def decrypt_password(token):
+	
+	try:
+		password = Fernet(get_machine_key()).decrypt(token.encode()).decode()
+	except InvalidToken:
+		password = ""
+	
+	return password
+
+def encrypt_connstr(connstr):
+	
+	parsed = parse_connstr(connstr)
+	if not parsed:
+		return connstr
+	if not parsed["password"]:
+		return connstr
+	
+	token = encrypt_password(parsed["password"])
+	connstr = "postgres://%s:-@%s/%s?currentSchema=%s" % (
+		parsed["username"],
+		parsed["host"], 
+		parsed["dbname"], 
+		parsed["schema"]
+	)
+	connstr = html.escape(token) + "\"" + html.escape(connstr)
+	
+	return connstr
+
+def decrypt_connstr(connstr):
+	
+	connstr_orig = connstr
+	connstr = connstr.split("\"")
+	if len(connstr) != 2:
+		return connstr_orig
+	token, connstr = connstr
+	token = html.unescape(token)
+	connstr = html.unescape(connstr)
+	parsed = parse_connstr(connstr)
+	if not parsed:
+		return connstr_orig
+	password = decrypt_password(token)
+	if not password:
+		return connstr_orig
+	connstr = "postgres://%s:%s@%s/%s?currentSchema=%s" % (
+		parsed["username"],
+		password,
+		parsed["host"], 
+		parsed["dbname"], 
+		parsed["schema"]
+	)
+	return connstr
+
